excerpts: excerpts.op Namespace Reference

excerpts

- Main Page
- Packages
- Files

- Packages
- Package Functions

All Namespaces Files Functions
Functions
excerpts.op Namespace Reference

## Functions
def | is_tool
| Test if a Program is Installed. More...
def | pandoc
| Run Pandoc on a File. More...

## Function Documentation

def excerpts.op.is_tool | ( |  | name | ) |

Test if a Program is Installed.

Will raise an error if the programm is not found.

Parameters

  name | The name of the program to be tested for.

Returns
  True if the Program is installed.

Here is the call graph for this function:

def excerpts.op.pandoc | ( |  | file_name,
|  |  | compile_latex = `False`,
|  |  | formats = `"tex"`
| ) |  |

Run Pandoc on a File.

file_name The file on which to run pandoc. formats The pandoc output formats to be used. compile_latex Compile the LaTeX file?

Returns
  0 if parsing was successful, 1 otherwise.

Here is the call graph for this function: